from helga.plugins import command

from functions import bounty_lookup, crucible_lookup, daily_lookup
from functions import heroic_lookup, nightfall_lookup, xur_lookup
from scraper import VENDOR_NAMES

guard_help = "Returns a guardian's destinytracker.com page"
@command('guardian', aliases=('g',), help=guard_help)
def guardian(client, channel, nick, message, cmd, args):
    if len(args) != 2:
        return 'Command takes 2 arguments: !guardian system name'
    system, name = args[0], args[1]
    return gurdian_lookup(system, name)

nf_help = 'Displays info on the current nightfall from destinytracker.com'

@command('nightfall', aliases=('nf',), help=nf_help)
def nightfall(client, channel, nick, message, cmd, args):
    return nightfall_lookup()

hero_help = 'Displays info on the current heroic from destinytracker.com'
@command('heroic', aliases=('hero',), help=hero_help)
def heroic(client, channel, nick, message, cmd, args):
    return heroic_lookup()

daily_help = 'Displays info on the current heroic daily from planetdestiny.com'
@command('daily', aliases=(), help=daily_help)
def daily(client, channel, nick, message, cmd, args):
    return daily_lookup()

crucible_help = 'Displays info on the current daily crucible mode form planetdestiny.com'
@command('crucible', aliases=(), help=crucible_help)
def crucible(client, channel, nick, message, cmd, args):
    return crucible_lookup()

@command('xur', aliases=(), help="Gives a URL for looking up Xur's inventory")
def xur(client, channel, nick, message, cmd, args):
    return xur_lookup()

valid_names = ' ,'.join(VENDOR_NAMES)
bounty_help = "Looks up the bounties for a given vendor. Valid names are: %s" % valid_names
@command('bounties', aliases=('b',), help=bounty_help)
def bounties(client, channel, nick, message, cmd, args):
    vendor_name = args[0]

    if vendor_name.title() not in VENDOR_NAMES:
        return "Invalid vendor. Valid names are: %s" % valid_names

    return bounty_lookup(vendor_name)



import datetime

from pytz import timezone

import caching as cache

from scraper import read_bounty_tables, ScrapeError, VENDOR_NAMES
from scraper import nightfall_info, heroic_info, daily_info, crucible_info, get_soup

VALID_SYSTEMS = ('ps', 'xbox')


def guardian_lookup(system, name):
    if system not in VALID_SYSTEMS:
        return '%s is not a valid system' % system
    link_template = 'http://destinytracker.com/destiny/overview/%(system)s/%(name)s'

    return link_template % {'system': system, 'name': name}

def xur_lookup():
    url_pattern = "http://www.vg247.com/%(year)s/%(month)s/%(friday)s/destiny-xur-location-and-inventory-for-%(month_name)s-%(friday)s-%(saturday)s"
    pacific = timezone('US/Pacific')
    today = datetime.datetime.today()

    pac_day = pacific.localize(today)

    day_name = pac_day.strftime('%A')

    if day_name not in ('Friday', 'Saturday'):
        return "Sorry, Xur isn't present right now."

    if day_name == 'Friday':
        friday = pac_day.day
        saturday = (pac_day + datetime.timedelta(days=1)).day
    elif day_name == 'Saturday':
        saturday = pac_day.day
        friday = (pac_day - datetime.timedelta(days=1)).day
    else:
        return "Something went wrong with the date math. I think today is %s" % day_name


    year = pac_day.year
    month = pac_day.month
    month_name = pac_day.strftime('%B')
    month_name = month_name.lower()

    url = url_pattern % {'year': year, 'month': month,
                         'month_name': month_name,
                         'friday': friday, 'saturday': saturday
                        }
    return url


def bounty_lookup(vendor):
    key = '%s-bounties' % vendor
    val = cache.read(key)
    if val is not None:
        return val

    try:
        bounties = read_bounty_tables(vendor)
    except ScrapeError as e:
        return e

    bounty_template = '%(name)s - %(desc)s'

    bounty_output = []
    for name, desc in bounties.items():
        line = bounty_template % {'name': name, 'desc': desc}
        bounty_output.append(line)

    out = '\n'.join(bounty_output)

    expiry = datetime.datetime.now() + datetime.timedelta(hours=1)

    cache.write(key, out, expiry)

    return out


def nightfall_lookup():
    val = cache.read('nightfall')
    if val is not None:
        return val

    soup = get_soup('http://db.planetdestiny.com')
    val = nightfall_info(soup)
    expiry = datetime.datetime.now() + datetime.timedelta(hours=1)

    cache.write('nightfall', val, expiry)

    return val


def heroic_lookup():
    val = cache.read('heroic')
    if val is not None:
        return val

    soup = get_soup('http://db.planetdestiny.com')
    val = heroic_info(soup)
    expiry = datetime.datetime.now() + datetime.timedelta(hours=1)

    cache.write('heroic', val, expiry)

    return val


def daily_lookup():
    val = cache.read('daily')
    if val is not None:
        return val

    val = daily_info()
    expiry = datetime.datetime.now() + datetime.timedelta(hours=1)

    cache.write('daily', val, expiry)

    return val


def crucible_lookup():
    val = cache.read('crucible')

    if val is not None:
        return val

    val = crucible_info()
    expiry = datetime.datetime.now() + datetime.timedelta(hours=1)

    cache.write('crucible', val, expiry)

    return val

if __name__ == '__main__':
    #print xur_lookup()
    print bounties('bad')
    print "----"
    print bounties('Eris')
    print "----"
    print bounties('Vanguard')




import datetime

import caching as cache

today = datetime.datetime.today()
yesterday = today + datetime.timedelta(days=-1)
tomorrow = today +datetime.timedelta(days=1)

def teardown_function(function):
    cache.clear()


def test_write():
    cache.write('test', '92', tomorrow)
    value = cache.read('test')
    assert value == '92'


def test_reading_expires_old_value():
    cache.write('test', '1', yesterday)
    value = cache.read('test')
    assert value == None


def test_writing_expires_old_value():
    cache.write('test', '1', yesterday)
    cache.write('test', '2', tomorrow)
    value = cache.read('test')
    assert value == '2'


def test_reading_nonexistent_key():
    val = cache.read('test')
    assert val is None


def test_writing_with_newer_expire():
    cache.write('test', '1', tomorrow)
    result = cache.write('test', '2', today)
    assert result == False

    val = cache.read('test')
    assert val == '1'



#!/usr/bin/env python

import sys

from functions import daily_lookup,  heroic_lookup, nightfall_lookup
from functions import bounty_lookup, crucible_lookup, VENDOR_NAMES

def check_bounties():
    bounties = []
    for name in VENDOR_NAMES:
        bounties.extend([name, '---'])
        bounties.append(bounty_lookup(name))
    return '\n'.join(bounties)


def main(command):
    cmd_map = {
        'daily': daily_lookup,
        'heroic': heroic_lookup,
        'nightfall': nightfall_lookup,
        'crucible': crucible_lookup,
        'bounties': check_bounties,

    }

    if command not in cmd_map.keys():
        return "%s was not a valid command" % command

    func = cmd_map[command]
    return func()


if __name__ == '__main__':
    command = sys.argv[1]
    print main(command)



from functools import partial
import requests
import bs4


template = "%(strike)s. Modifiers: %(mods)s"
event_url = 'http://destinytracker.com/destiny/events'

class ScrapeError(Exception):
    pass


def find_term(soup, term):
    lists = soup.select('ul')
    for idx, ul in enumerate(lists):
        if term in ul.text:
            return idx
    return None

def get_mods(soup, term):
    index = find_term(soup, term)
    if index is None:
        return ''

    mod_list = soup.select('ul')[index]

    modifiers = [li.text for li in mod_list.select('li')]
    modifiers = ', '.join(modifiers)

    return modifiers


def get_soup(event_url=event_url):
    response = requests.get(event_url)
    html = response.text

    soup = bs4.BeautifulSoup(response.text)
    return soup


def strike_title(soup):
    title = soup.select('h4.media-heading')[-1].text
    return title


NIGHTFALL = 'nightfall'
WEEKLY_HEROIC = 'weekly heroic'

def weekly_lockout_event_info(soup, event):
    """:param soup: the document to search through
       :param event: the name of the event (should be either
                     ``NIGHTFALL`` or ``WEEKLY_HEROIC`` as defined in the
                     ``scraper`` module).
    """

    # FIXME: the next() call will raise if it doesn't find at least one node
    title = next(i for i in soup.select('div.activity-title')
                 if event in i.text.lower())
    root = title.findParent().findParent().findParent()
    return template % {
        'strike': title.findNextSibling().text,
        'mods': ', '.join(i.text for i in root.select('.tooltip-caption'))}


def nightfall_info(soup):
    return weekly_lockout_event_info(soup, NIGHTFALL)


def heroic_info(soup):
    return weekly_lockout_event_info(soup, WEEKLY_HEROIC)


def daily_info():
    soup = get_soup("http://db.planetdestiny.com/events")

    title = soup.select('div.activity-title')[0].text
    title = title.strip()

    mod_list = soup.select('div.tooltip-caption')[0:2]
    modifiers = [div.text for div in mod_list]
    modifiers = ', '.join(modifiers)

    return template % {'strike': title, 'mods': modifiers}


def crucible_info():
    soup = get_soup("http://db.planetdestiny.com/events")

    act_titles = soup.select('div.activity-title')
    mode_title = act_titles[1].text.strip()

    return "Daily Crucible mode: %s" % mode_title


VENDOR_NAMES = [
    'eris',
    'crucible',
    'vanguard',
]

def find_tables(vendor):
    soup = get_soup("http://db.planetdestiny.com/events")
    headers = soup.select('h3')
    target_index = None
    for index, header in enumerate(headers):
        if vendor in header.text.lower():
            target_index = index
            break

    table = soup.select('table')[target_index]

    return table

def read_bounty_tables(vendor):
    vendor = vendor.lower()
    table = find_tables(vendor)

    # The first row is the heading
    rows = table.select('tr')[1:]

    bounties = {}
    for row in rows:
        cells = row.select('td')
        name = cells[0].select('a')[0].text
        name = name.strip()

        desc = cells[1].text.strip()

        bounties[name] = desc

    return bounties


if __name__ == '__main__':
    weekly_soup = get_soup('http://db.planetdestiny.com')
    print nightfall_info(weekly_soup)
    print heroic_info(weekly_soup)
    # soup = get_soup()
    # print daily_info()
    # print crucible_info()
    # print bounty_info('Vanguard')
    # print "---"
    # print bounty_info('Crucible')
    # print "---"
    # print bounty_info('Eris')
